RemoveComponentError

Enum RemoveComponentError 

pub enum RemoveComponentError {
    EntityNotFound,
    ComponentNotRegistered,
    ComponentNotPresent,
}
Errors that can occur when removing a single component from an entity.

Variants



EntityNotFound

The specified entity does not exist or is not alive.



ComponentNotRegistered

The specified component type is not registered in the ECS.



ComponentNotPresent

The entity does not currently have a component of the specified type.