SetFromBytesError

Enum SetFromBytesError 

pub enum SetFromBytesError {
    MisalignedLength {
        len: usize,
        elem_size: usize,
    },
    PayloadTooLarge {
        len: usize,
        max: usize,
    },
}
Error returned when raw column bytes fail validation in AnyVec::set_from_bytes.

Variants



MisalignedLength

The byte length is not an exact multiple of the column’s element size, so it cannot describe a whole number of elements.

Fields

len: usize

Length of the supplied byte buffer.

elem_size: usize

Size of a single element in the column.



PayloadTooLarge

The byte length exceeds MAX_COLUMN_PAYLOAD_BYTES.

Fields

len: usize

Length of the supplied byte buffer.

max: usize

The maximum accepted payload size.