serialize_material_component

Function serialize_material_component 

pub fn serialize_material_component(
    base_color: LinearRgba,
    material: &dyn Material,
) -> Option<Vec<u8>>
Serializes a dyn Material by finding the matching MaterialRegistration and encoding the material data with its type name.