ComponentPage

Struct ComponentPage 

pub struct ComponentPage { /* private fields */ }
A page of memory that stores the component data for multiple entities in a Structure of Arrays (SoA) layout.

A ComponentPage is specialized for a single semantic domain (e.g., physics). It contains multiple columns, where each column is a Vec<T> for a specific component type T. This SoA layout is the key to our high iteration performance, as it guarantees contiguous data access for native queries.