pub struct DomainBitset { /* private fields */ }Expand description
A simple bitset wrapped around a Vec<u64>.
This structure is used to track which entities have components in a specific
SemanticDomain. It allows for extremely fast (bitwise) filtering during
transversal queries.
Implementations
Sourceimpl DomainBitset
impl DomainBitset
Sourcepub fn get_block(&self, word_idx: usize) -> u64
pub fn get_block(&self, word_idx: usize) -> u64
Returns the 64-bit block at the specified word index. Returns 0 if the index is out of bounds.
Sourcepub fn is_set(&self, index: u32) -> bool
pub fn is_set(&self, index: u32) -> bool
Returns true if the bit at the specified index is set.
Sourcepub fn intersect(&mut self, other: &DomainBitset)
pub fn intersect(&mut self, other: &DomainBitset)
Performs a bitwise AND with another bitset.