pub struct Transform {
pub translation: Vec3,
pub rotation: Quaternion,
pub scale: Vec3,
}Expand description
A component that describes an entity’s position, rotation, and scale
relative to its Parent. If the entity has no Parent, this is relative
to the world origin.
This is the component that users and other systems should modify. A dedicated
transform propagation system will use this component’s value to calculate
the final GlobalTransform.
Fields
translation: Vec3The translation (position) of the entity.
rotation: QuaternionThe rotation of the entity, represented as a quaternion.
scale: Vec3The scale of the entity.
Implementations
Sourceimpl Transform
impl Transform
Sourcepub fn new(translation: Vec3, rotation: Quaternion, scale: Vec3) -> Self
pub fn new(translation: Vec3, rotation: Quaternion, scale: Vec3) -> Self
Creates a new Transform with a given translation, rotation, and scale.
Sourcepub fn from_translation(translation: Vec3) -> Self
pub fn from_translation(translation: Vec3) -> Self
Creates a new Transform with a given translation, and identity rotation/scale.