pub fn submit_frame_graph(
graph: &SharedFrameGraph,
device: &dyn GraphicsDevice,
) -> usizeExpand description
Drains graph and submits every recorded command buffer in topological
order. Returns the number of submitted buffers.
pub fn submit_frame_graph(
graph: &SharedFrameGraph,
device: &dyn GraphicsDevice,
) -> usizeDrains graph and submits every recorded command buffer in topological
order. Returns the number of submitted buffers.