Struct ShadowEntries
pub struct ShadowEntries(pub HashMap<usize, ShadowEntry>);Expand description
Per-frame shadow lookup keyed by light index in RenderWorld.lights.
Tuple Fields
0: HashMap<usize, ShadowEntry>Implementations
impl ShadowEntries
impl ShadowEntries
pub fn insert(&mut self, light_index: usize, entry: ShadowEntry)
pub fn insert(&mut self, light_index: usize, entry: ShadowEntry)
Inserts (or replaces) shadow data for the light at light_index.
pub fn get(&self, light_index: usize) -> Option<&ShadowEntry>
pub fn get(&self, light_index: usize) -> Option<&ShadowEntry>
Looks up shadow data for the light at light_index.