DefinitionSerializationStrategy

Struct DefinitionSerializationStrategy 

pub struct DefinitionSerializationStrategy;
A serialization strategy that uses a stable, intermediate representation.

Iterates all registered components via inventory to serialize every component on every entity. The output is human-readable RON with base64-encoded binary component data.

Implementations

Source

impl DefinitionSerializationStrategy

pub fn new() -> Self

Creates a new DefinitionSerializationStrategy.