pub struct ComponentRegistry { /* private fields */ }Expand description
A registry that maps component types to their semantic domains.
This is a critical internal part of the World. It provides a single source
of truth for determining which semantic group a component’s data belongs to,
enabling the World to correctly store and retrieve component data from pages.
Implementations
Sourceimpl ComponentRegistry
impl ComponentRegistry
Sourcepub fn get_domain(&self, type_id: TypeId) -> Option<SemanticDomain>
pub fn get_domain(&self, type_id: TypeId) -> Option<SemanticDomain>
Looks up the SemanticDomain for a given TypeId.