pub struct GlobalTransform(pub AffineTransform);Expand description
A component that stores the final, calculated, world-space transformation of an entity.
This component’s value is the result of combining the entity’s local Transform
with the GlobalTransform of its Parent, recursively up to the root of the scene.
It is intended to be read-only for most systems (like rendering and physics). It should only be written to by the dedicated transform propagation system. This acts as a cache to avoid re-calculating the full transform hierarchy every time it’s needed.
Tuple Fields
0: AffineTransformImplementations
Sourceimpl GlobalTransform
impl GlobalTransform
Sourcepub fn at_position(position: Vec3) -> Self
pub fn at_position(position: Vec3) -> Self
Creates a GlobalTransform representing a translation.