pub trait WorldMaintenance {
// Required methods
fn cleanup_orphan_at(&mut self, location: PageIndex, domain: SemanticDomain);
fn vacuum_hole_at(&mut self, page_index: u32, hole_row_index: u32);
}Expand description
A trait providing low-level access to the World for maintenance tasks.
Required Methods
Sourcefn cleanup_orphan_at(&mut self, location: PageIndex, domain: SemanticDomain)
fn cleanup_orphan_at(&mut self, location: PageIndex, domain: SemanticDomain)
Cleans up an orphaned data slot in a page.
Sourcefn vacuum_hole_at(&mut self, page_index: u32, hole_row_index: u32)
fn vacuum_hole_at(&mut self, page_index: u32, hole_row_index: u32)
Vacuums a hole in a page by moving the last entity into it.
Arguments
page_index- The index of the page containing the hole.hole_row_index- The row index of the hole to be filled.